@@ -38,7 +38,7 @@ class Model(object):
         self.table = table
         self.primary_key = pk
 
-        self.cur.execute('SELECT * FROM '+ self.table +' LIMIT 0',(self.table,))
+        self.cur.execute('SELECT * FROM "' + self.table + '" LIMIT 0',(self.table,))
         self.columns = [desc[0] for desc in self.cur.description]
 
         # Alias
@@ -86,24 +86,25 @@ class Model(object):
                 'column' : attr,
                 'value' : val
             })
-        # If primary key is set, update else insert
-        if self.__dict__[self.primary_key] != None and type(self.__dict__[self.primary_key]) == int:
+
+        # Insert by default, unless a row exists in the db with the same pk value
+        qry_fields = ", ".join([ field['column'] for field in ae_fields ])
+        qry_values = ", ".join([ str(field['value']) if type(field['value']) != dict else json.dumps(field['value']) for field in ae_fields  ])
+        qry = 'INSERT INTO "%s" ('+ qry_fields +') VALUES (' + ', '.join([ '%s' for i in range(0,len(ae_fields)) ]) + ') RETURNING %s'
+        # If primary key is set, check if we need to update or insert
+        if self.__dict__[self.primary_key] != None:
             # Set primary key value
             self.pkv =  self.__dict__[self.primary_key]
-            # Build update query
-            qry_fields = ", ".join([ field['column'] for field in ae_fields ])
-            qry_values = ", ".join([ str(field['value']) for field in ae_fields ])
-            qry = "UPDATE  %s SET ("+ qry_fields +") = (" + ", ".join([ "%s" for i in range(0,len(ae_fields)) ]) + ") WHERE %s = %s RETURNING %s"
-        else:
-            # Build insert query
-            qry_fields = ", ".join([ field['column'] for field in ae_fields ])
-            qry_values = ", ".join([ str(field['value']) for field in ae_fields ])
-            qry = "INSERT INTO %s ("+ qry_fields +") VALUES (" + ", ".join([ "%s" for i in range(0,len(ae_fields)) ]) + ") RETURNING %s"
+            # Check if record exists in the db
+            self.cur.execute('SELECT * FROM "%s" WHERE %s = %s LIMIT 1 ', [AsIs(self.table),AsIs(self.primary_key),self.pkv])
+            rc = self.cur.rowcount
+            if rc > 0:
+                qry = 'UPDATE  "%s" SET ('+ qry_fields +') = (' + ', '.join([ '%s' for i in range(0,len(ae_fields)) ]) + ') WHERE %s = %s RETURNING %s'
 
         self.cur.execute(qry, \
             [AsIs(self.table)] + \
-            [ str(field['value']) for field in ae_fields ] + \
-            ( [AsIs(self.primary_key),AsIs(self.pkv)] if self.pkv else [] ) + \
+            [ str(field['value']) if type(field['value']) != dict else json.dumps(field['value']) for field in ae_fields ] + \
+            ( [AsIs(self.primary_key),self.pkv] if qry.split(" ")[0] == 'UPDATE' else [] ) + \
             [AsIs(self.primary_key)] \
         )
 
@@ -117,6 +118,42 @@ class Model(object):
         if clear:
             self.clear()
 
+
+
+    def insert(self,commit=True,clear=True):
+        ''' Always insert  in table, must have primary key
+        '''
+        # Insert or update only to the columns that have some value
+        ae_fields = []
+        for attr, val in self.__dict__.items():
+            if attr not in self.columns or val == None:
+                continue
+            ae_fields.append({
+                'column' : attr,
+                'value' : val
+            })
+
+        # Generate of not generate primary key value
+        qry_fields = ", ".join([ field['column'] for field in ae_fields ])
+        qry_values = ", ".join([ str(field['value']) for field in ae_fields ])
+        qry = 'INSERT INTO "%s" ('+ qry_fields +') VALUES (' + ', '.join([ '%s' for i in range(0,len(ae_fields)) ]) + ') RETURNING %s'
+
+        self.cur.execute(qry, \
+            [AsIs(self.table)] + \
+            [ str(field['value']) for field in ae_fields ] + \
+            [AsIs(self.primary_key)] \
+        )
+        self.last_id = self.cur.fetchone()[0]
+        setattr(self, self.primary_key, self.last_id)
+        setattr(self, 'pkv', self.last_id)
+        # If commit parameter is false, do not commit
+        if commit:
+            self.conn.commit()
+        # clear attributes
+        if clear:
+            self.clear()
+
+
     def clear(self):
         ''' Clear column attributes from instance
         '''
@@ -151,7 +188,7 @@ class Model(object):
 
         self.cur.execute(
             """
-            DELETE FROM %s WHERE %s IN ( """ + ", ".join([ "%s" for i in range(0,len(ids)) ]) + """ )
+            DELETE FROM "%s" WHERE %s IN ( """ + ", ".join([ "%s" for i in range(0,len(ids)) ]) + """ )
             """,
             [ AsIs(self.table), AsIs(self.primary_key) ] + \
             ids
@@ -173,12 +210,12 @@ class Model(object):
             pkv = args[0]
         rows = self.pygres.query(
             """
-            SELECT * FROM %s WHERE %s = %s
+            SELECT * FROM "%s" WHERE %s = %s
             """,
             (AsIs(self.table),AsIs(self.primary_key),pkv)
         ).fetch()
-        if rows == None:
-            return []
+        if rows == None or len(rows) <= 0:
+            return None
         # Instantiate values
         for k,v in rows[0].items():
             setattr(self,k,v)
@@ -200,17 +237,17 @@ class Model(object):
         # Statement
         rows = self.pygres.query(
             """
-            SELECT * FROM %s WHERE ("""+  ' AND '.join( [ "%s=%s" for i in range(0,len(kwargs)) ] )  +""")
+            SELECT * FROM "%s" WHERE ("""+  ' AND '.join( [ "%s=%s" for i in range(0,len(kwargs)) ] )  +""")
             """,
             [ AsIs(self.table) ] + \
             combined \
         ).fetch()
-        if rows == None:
+        if rows == None or len(rows) <= 0:
             return []
 
         self.clear()
+        self.rows = rows
         if len(rows) > 1:
-            self.rows = rows
             ret = rows
         else:
             ret = rows[0]
@@ -224,7 +261,7 @@ class Model(object):
 
     # Query price table
     def select(self,fields="*"):
-        self.query['select'] = "select %s from %s " % (fields, self.table)
+        self.query['select'] = 'select %s from "%s" ' % (fields, self.table)
         return self
 
     def where(self,clause):
@@ -248,7 +285,7 @@ class Model(object):
         Build SQL query and fetch rows
         '''
         # Build SQL query
-        query = self.qry['select'] if 'select' in self.qry and self.qry['select'] != None else "select * from %s " % self.table
+        query = self.qry['select'] if 'select' in self.qry and self.qry['select'] != None else 'select * from "%s" ' % self.table
         query += self.qry['join'] if 'join' in self.qry and  self.qry['join'] != None else ""
         query += self.qry['where'] if 'where' in self.qry and self.qry['where'] != None else ""
         query += self.qry['group_by'] if 'group_by' in self.qry and self.qry['group_by'] != None else ""
